----------------------------------------------------------------------------------------------------
-- FuBar 3 Plugin for Wardrobe-AL
-- Author: Swizstera
-- Date: 10/27/2008
--
-- prototype shamelessly taken from Broker2FuBar implementation
----------------------------------------------------------------------------------------------------


-- do nothing if FuBar isn't present
if not FuBar2DB then return end

local LFBP = LibStub:GetLibrary("LibFuBarPlugin-3.0")

WardrobeAce.pluginPrototype = {}
WardrobeAce.pluginPrototypeMetatable = { __index = WardrobeAce.pluginPrototype }

local pluginPrototype = WardrobeAce.pluginPrototype


----------------------------------------------------------------------------------------------------

function WardrobeAce:InitFuBarPlugin()

		WardrobeAce.FuBarPlugin = setmetatable({
				name             = "Wardrobe",
			}, self.pluginPrototypeMetatable)

		LFBP:Embed(WardrobeAce.FuBarPlugin)

		WardrobeAce.FuBarPlugin:Initialize()

end

function WardrobeAce:ToggleFuBarPlugin()

	  db.fubar.enabled = not db.fubar.enabled

	  if(db.fubar.enabled) then
	    WardrobeAce:OnEnableFuBarPlugin()
	  else
		WardrobeAce:OnDisableFuBarPlugin()
	  end

end

function WardrobeAce:OnEnableFuBarPlugin()

	WardrobeAce.FuBarPlugin:Enable()

	self:RegisterEvent("UNIT_INVENTORY_CHANGED")

end

function WardrobeAce:OnDisableFuBarPlugin()
	if not WardrobeAce.FuBarPlugin then return end

	self:UnregisterEvent("UNIT_INVENTORY_CHANGED")

	WardrobeAce.FuBarPlugin:Disable()

end

-- UNIT_INVENTORY_CHANGED event
function WardrobeAce:UNIT_INVENTORY_CHANGED()

	if not WardrobeAce.FuBarPlugin then return end

	-- update the text on the panel
	if (Chronos) then
		Chronos.scheduleByName("WardrobeFuUpdate", .2, function() WardrobeAce.FuBarPlugin:OnFuBarUpdateText() end)
	else
		WardrobeAce.FuBarPlugin:OnFuBarUpdateText()
	end

end



----------------------------------------------------------------------------------------------------

function pluginPrototype:Initialize()

	self:SetFuBarOption("cannotAttachToMinimap", true)
	self:SetFuBarOption("tooltipType", "GameTooltip")
	self:SetFuBarOption("hasNoColor", false)
	self:SetFuBarOption("cannotDetachTooltip", true)
	self:SetFuBarOption("hideWithoutStandby", true)
	self:SetFuBarOption("iconPath", [[Interface\AddOns\Wardrobe\Images\Wardrobe]])
	self:SetFuBarOption("hasIcon", true)
	self:SetFuBarOption("defaultPosition", "RIGHT")
	self:SetFuBarOption("tooltipHiddenWhenEmpty", true)
	self:SetFuBarOption('configType', 'None')
	LFBP:OnEmbedInitialize(self)

end

function pluginPrototype:Enable()

	if self.enabled then return end
	self.enabled = true
	LFBP:OnEmbedEnable(self)

	if(FuBar:GetNumPanels() == 0) then
		return
	end

--	if (not db.fubar.panelId or db.fubar.panelId > FuBar:GetNumPanels()) then
	if (db.fubar.panelId > FuBar:GetNumPanels()) then
		db.fubar.panelId = 1
	end

	local panel = FuBar:GetPanel(db.fubar.panelId)

	panel:AddPlugin(self, nil, db.fubar.position)
	self:SetPanel(panel)

	self:OnFuBarUpdateText()

end

function pluginPrototype:Disable()
	if not self.enabled then return end
	self.enabled = false
	LFBP:OnEmbedDisable(self)
end

function pluginPrototype:IsEnabled()
	return self.enabled
end


function pluginPrototype:OnFuBarClick(button, down)

	if(button == "RightButton") then
		Wardrobe.RightClickOpenFunction[Wardrobe_Config.RightClickOpenFunction].func()
	else
		self:ShowWardrobeMenu()
	end
end


-- Show the wardrobe popup menu at the cursor
function pluginPrototype:ShowWardrobeMenu()

	ToggleDropDownMenu(1, nil, WardrobeEquipDropDown, "cursor")

end


function pluginPrototype:OnUpdateFuBarTooltip()

	if Wardrobe_Config.MustClickUIButton then
		local menustring = Wardrobe.RightClickOpenFunction[Wardrobe_Config.RightClickOpenFunction].desc

		GameTooltip:AddLine("|cffffff00" .. L["Select your outfit or configure Wardrobe"])
		GameTooltip:AddLine("|cffffff00" .. L["Right-click|r to "]..menustring)
	end

end

function pluginPrototype:OnFuBarEnter(motion)

	if not Wardrobe_Config.MustClickUIButton then
		self:ShowWardrobeMenu()
	end

end

-- Update the text value to appear on the FuBar
function pluginPrototype:OnFuBarUpdateText()

	if(db.fubar.enabled) then
		-- get the list of outfits
		local outfitText = Wardrobe.GetActiveOutfitsTextList()

		-- prepend the label
		if (db.fubar.showTextPrefix) then
			outfitText = L["Wardrobe: "]..outfitText
		end

		-- set the text
		self:SetFuBarText(outfitText)
	end

end
